
Imports System
Imports System.Drawing
Imports System.Collections
Imports System.ComponentModel
Imports System.Windows.Forms
Imports System.Data

Imports Syncfusion.Windows.Forms.Grid.Grouping
Imports Syncfusion.Grouping


'/ <summary>
'/ This sample demonstrates how to manually specify master-details relations 
'/ between three separate tables that primary keys and foreign key columns
'/ in common. 
'/ </summary>

Public Class Form1
    Inherits System.Windows.Forms.Form
    Private gridGroupingControl1 As Syncfusion.Windows.Forms.Grid.Grouping.GridGroupingControl
    Private components As System.ComponentModel.Container = Nothing


    Public Sub New()
        InitializeComponent()
    End Sub 'New


    '/ <summary>
    '/ Clean up any resources being used.
    '/ </summary>
    Protected Overloads Overrides Sub Dispose(ByVal disposing As Boolean)
        If disposing Then
            If Not (components Is Nothing) Then
                components.Dispose()
            End If
        End If
        MyBase.Dispose(disposing)
    End Sub 'Dispose

#Region "Windows Form Designer generated code"

    '/ <summary>
    '/ Required method for Designer support - do not modify
    '/ the contents of this method with the code editor.
    '/ </summary>
    Private Sub InitializeComponent()
        Me.gridGroupingControl1 = New Syncfusion.Windows.Forms.Grid.Grouping.GridGroupingControl()
        CType(Me.gridGroupingControl1, System.ComponentModel.ISupportInitialize).BeginInit()
        Me.SuspendLayout()
        ' 
        ' gridGroupingControl1
        ' 
        Me.gridGroupingControl1.Anchor = System.Windows.Forms.AnchorStyles.Top Or System.Windows.Forms.AnchorStyles.Bottom Or System.Windows.Forms.AnchorStyles.Left Or System.Windows.Forms.AnchorStyles.Right
        Me.gridGroupingControl1.BackColor = System.Drawing.SystemColors.Window
        Me.gridGroupingControl1.Location = New System.Drawing.Point(16, 40)
        Me.gridGroupingControl1.Name = "gridGroupingControl1"
        Me.gridGroupingControl1.Size = New System.Drawing.Size(644, 356)
        Me.gridGroupingControl1.TabIndex = 0
        Me.gridGroupingControl1.TableDescriptor.Name = "Default"
        Me.gridGroupingControl1.Text = "gridGroupingControl1"
        ' 
        ' Form1
        ' 
        Me.AutoScaleBaseSize = New System.Drawing.Size(5, 13)
        Me.ClientSize = New System.Drawing.Size(680, 414)
        Me.Controls.AddRange(New System.Windows.Forms.Control() {Me.gridGroupingControl1})
        Me.Name = "Form1"
        Me.Text = "Form1"
        CType(Me.gridGroupingControl1, System.ComponentModel.ISupportInitialize).EndInit()
        Me.ResumeLayout(False)
    End Sub 'InitializeComponent 
#End Region


    '/ <summary>
    '/ The main entry point for the application.
    '/ </summary>
    <STAThread()> _
    Shared Sub Main()
        Application.Run(New Form1())
    End Sub 'Main


    Private Sub Form1_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Dim parentTable As DataTable = GetParentTable()
        Dim childTable As DataTable = GetChildTable()
        Dim grandChildTable As DataTable = GetGrandChildTable()

        ' Manually specify relations in grouping engine. The DataSet does not need to have any DataRelations.
        ' This is the same approach that should be used if you want to set up relation ships
        ' between independent IList.
        Dim parentToChildRelationDescriptor As New GridRelationDescriptor()
        parentToChildRelationDescriptor.ChildTableName = "MyChildTable" ' same as SourceListSetEntry.Name for childTable (see below)
        parentToChildRelationDescriptor.RelationKind = RelationKind.RelatedMasterDetails
        parentToChildRelationDescriptor.RelationKeys.Add("parentID", "ParentID")

        ' Add relation to ParentTable 
        gridGroupingControl1.TableDescriptor.Relations.Add(parentToChildRelationDescriptor)

        Dim childToGrandChildRelationDescriptor As New GridRelationDescriptor()
        childToGrandChildRelationDescriptor.ChildTableName = "MyGrandChildTable" ' same as SourceListSetEntry.Name for grandChhildTable (see below)
        childToGrandChildRelationDescriptor.RelationKind = RelationKind.RelatedMasterDetails
        childToGrandChildRelationDescriptor.RelationKeys.Add("childID", "ChildID")

        ' Add relation to ChildTable 
        parentToChildRelationDescriptor.ChildTableDescriptor.Relations.Add(childToGrandChildRelationDescriptor)

        ' Register any DataTable/IList with SourceListSet, so that RelationDescriptor can resolve the name
        Me.gridGroupingControl1.Engine.SourceListSet.Add("MyParentTable", parentTable)
        Me.gridGroupingControl1.Engine.SourceListSet.Add("MyChildTable", childTable)
        Me.gridGroupingControl1.Engine.SourceListSet.Add("MyGrandChildTable", grandChildTable)

        Me.gridGroupingControl1.DataSource = parentTable
    End Sub 'Form1_Load


    Private numberParentRows As Integer = 5
    Private numberChildRows As Integer = 20
    Private numberGrandChildRows As Integer = 50



    Private Function GetParentTable() As DataTable
        Dim dt As New DataTable("ParentTable")


        dt.Columns.Add(New DataColumn("parentID")) 'lower case p
        dt.Columns.Add(New DataColumn("ParentName"))
        dt.Columns.Add(New DataColumn("ParentDec"))

        Dim i As Integer
        For i = 0 To numberParentRows - 1
            Dim dr As DataRow = dt.NewRow()
            dr(0) = i '.ToString();
            dr(1) = String.Format("parentName{0}", i)
            dr(1) = String.Format("parentName{0}", i)
            dt.Rows.Add(dr)
        Next i

        Return dt
    End Function 'GetParentTable


    Private Function GetChildTable() As DataTable
        Dim dt As New DataTable("ChildTable")

        dt.Columns.Add(New DataColumn("childID")) 'lower case c
        dt.Columns.Add(New DataColumn("Name"))
        dt.Columns.Add(New DataColumn("ParentID")) 'upper case P
        Dim i As Integer
        For i = 0 To numberChildRows - 1
            Dim dr As DataRow = dt.NewRow()
            dr(0) = i.ToString()
            dr(1) = String.Format("ChildName{0}", i)
            dr(2) = (i Mod numberParentRows).ToString()
            dt.Rows.Add(dr)
        Next i

        Return dt
    End Function 'GetChildTable


    Private Function GetGrandChildTable() As DataTable
        Dim dt As New DataTable("GrandChildTable")

        dt.Columns.Add(New DataColumn("GrandChildID"))
        dt.Columns.Add(New DataColumn("Name"))
        dt.Columns.Add(New DataColumn("ChildID")) 'upper case C
        Dim i As Integer
        For i = 0 To numberGrandChildRows - 1
            Dim dr As DataRow = dt.NewRow()
            dr(0) = i.ToString()
            dr(1) = String.Format("GrandChildName{0}", i)
            dr(2) = (i Mod numberChildRows).ToString()
            dt.Rows.Add(dr)
        Next i

        Return dt
    End Function 'GetGrandChildTable

End Class 'Form1